@@ -12,9 +12,10 @@ class Task:
         "fn",
         "wakaq",
         "queue",
+        "max_retries",
     ]
 
-    def __init__(self, fn=None, wakaq=None, queue=None):
+    def __init__(self, fn=None, wakaq=None, queue=None, max_retries=None):
         self.name = fn.__name__
         self.wakaq = wakaq
         if queue:
@@ -22,6 +23,8 @@ class Task:
         else:
             self.queue = None
 
+        self.max_retries = int(max_retries) if max_retries else None
+
         @wraps(fn)
         def inner(*args, **kwargs):
             return fn(*args, **kwargs)
